#!/usr/bin/perl
# -*- coding: utf-8 -*-
########################################################################
#
# gcount.pl
# Häufigkeit der Glyphen auf den einzelnen Seiten bestimmen.
#
########################################################################

use strict;
use warnings;

my $page = '';
my %cnt;
my %ctot;

sub print_and_reset_count
{
    my ($glyph, $freq);

    return unless ($page);
    foreach $glyph (sort { $cnt{$b} <=> $cnt{$a} } keys %cnt)
    {
	$freq = $cnt{$glyph};
	printf "%s\t%s\t%4d\n", $page, $glyph, $freq;
    }
    %cnt = ();
}

sub print_at_eof
{
    my ($glyph, $freq);

    print_and_reset_count ();
    foreach $glyph (sort { $ctot{$b} <=> $ctot{$a} } keys %ctot)
    {
	$freq = $ctot{$glyph};
	printf "total\t%s\t%4d\n", $glyph, $freq;
    }
}

sub process_line
{
    my ($line) = @_;
    my ($fnum, $glyph);

    return unless ($line =~ m/^\<(f[^\.]+)\./);
    $fnum = $1;
    if ($fnum ne $page)
    {
	print_and_reset_count ();
	$page = $fnum;
    }
    $line =~ s/^\<[^\>]+\>\s*//;
    foreach $glyph (split //, $line)
    {
	$cnt{$glyph}++;
	$ctot{$glyph}++;
    }
}

sub process_input
{
    while (<>)
    {
	chomp;
	process_line ($_);
    }
    print_at_eof ();
}

process_input ();
